@@ -1,58 +1,17 @@
 <?php
-/**
- * PHPUnit
+/*
+ * This file is part of PHPUnit.
  *
- * Copyright (c) 2001-2014, Sebastian Bergmann <sebastian@phpunit.de>.
- * All rights reserved.
+ * (c) Sebastian Bergmann <sebastian@phpunit.de>
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *   * Redistributions of source code must retain the above copyright
- *     notice, this list of conditions and the following disclaimer.
- *
- *   * Redistributions in binary form must reproduce the above copyright
- *     notice, this list of conditions and the following disclaimer in
- *     the documentation and/or other materials provided with the
- *     distribution.
- *
- *   * Neither the name of Sebastian Bergmann nor the names of his
- *     contributors may be used to endorse or promote products derived
- *     from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- *
- * @package    PHPUnit
- * @subpackage Util
- * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2001-2014 Sebastian Bergmann <sebastian@phpunit.de>
- * @license    http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
- * @link       http://www.phpunit.de/
- * @since      File available since Release 3.2.0
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
  */
 
 /**
  * XML helpers.
  *
- * @package    PHPUnit
- * @subpackage Util
- * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2001-2014 Sebastian Bergmann <sebastian@phpunit.de>
- * @license    http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
- * @link       http://www.phpunit.de/
- * @since      Class available since Release 3.2.0
+ * @since Class available since Release 3.2.0
  */
 class PHPUnit_Util_XML
 {
@@ -64,7 +23,6 @@ class PHPUnit_Util_XML
      *
      * @param  string $string
      * @return string
-     * @author Kore Nordmann <mail@kore-nordmann.de>
      * @since  Method available since Release 3.4.6
      */
     public static function prepareString($string)
@@ -73,7 +31,9 @@ class PHPUnit_Util_XML
             '/[\\x00-\\x08\\x0b\\x0c\\x0e-\\x1f\\x7f]/',
             '',
             htmlspecialchars(
-                PHPUnit_Util_String::convertToUtf8($string), ENT_QUOTES, 'UTF-8'
+                PHPUnit_Util_String::convertToUtf8($string),
+                ENT_QUOTES,
+                'UTF-8'
             )
         );
     }
@@ -82,9 +42,9 @@ class PHPUnit_Util_XML
      * Loads an XML (or HTML) file into a DOMDocument object.
      *
      * @param  string      $filename
-     * @param  boolean     $isHtml
-     * @param  boolean     $xinclude
-     * @param  boolean     $strict
+     * @param  bool        $isHtml
+     * @param  bool        $xinclude
+     * @param  bool        $strict
      * @return DOMDocument
      * @since  Method available since Release 3.3.0
      */
@@ -121,15 +81,12 @@ class PHPUnit_Util_XML
      * DOMDocument, use loadFile() instead.
      *
      * @param  string|DOMDocument $actual
-     * @param  boolean            $isHtml
+     * @param  bool               $isHtml
      * @param  string             $filename
-     * @param  boolean            $xinclude
-     * @param  boolean            $strict
+     * @param  bool               $xinclude
+     * @param  bool               $strict
      * @return DOMDocument
      * @since  Method available since Release 3.3.0
-     * @author Mike Naberezny <mike@maintainable.com>
-     * @author Derek DeVries <derek@maintainable.com>
-     * @author Tobias Schlitt <toby@php.net>
      */
     public static function load($actual, $isHtml = false, $filename = '', $xinclude = false, $strict = false)
     {
@@ -140,7 +97,7 @@ class PHPUnit_Util_XML
         // Required for XInclude on Windows.
         if ($xinclude) {
             $cwd = getcwd();
-            chdir(dirname($filename));
+            @chdir(dirname($filename));
         }
 
         $document  = new DOMDocument;
@@ -172,7 +129,7 @@ class PHPUnit_Util_XML
         error_reporting($reporting);
 
         if ($xinclude) {
-            chdir($cwd);
+            @chdir($cwd);
         }
 
         if ($loaded === false || ($strict && $message !== '')) {
@@ -193,8 +150,6 @@ class PHPUnit_Util_XML
     }
 
     /**
-     *
-     *
      * @param  DOMNode $node
      * @return string
      * @since  Method available since Release 3.4.0
@@ -215,11 +170,8 @@ class PHPUnit_Util_XML
     }
 
     /**
-     *
-     *
      * @param DOMNode $node
      * @since  Method available since Release 3.3.0
-     * @author Mattis Stordalen Flister <mattis@xait.no>
      */
     public static function removeCharacterDataNodes(DOMNode $node)
     {
@@ -244,7 +196,7 @@ class PHPUnit_Util_XML
         $variable = null;
 
         switch ($element->tagName) {
-            case 'array': {
+            case 'array':
                 $variable = array();
 
                 foreach ($element->getElementsByTagName('element') as $element) {
@@ -256,10 +208,9 @@ class PHPUnit_Util_XML
                         $variable[] = $value;
                     }
                 }
-                }
-            break;
+                break;
 
-            case 'object': {
+            case 'object':
                 $className = $element->getAttribute('class');
 
                 if ($element->hasChildNodes()) {
@@ -277,22 +228,19 @@ class PHPUnit_Util_XML
                 } else {
                     $variable = new $className;
                 }
-                }
-            break;
+                break;
 
-            case 'boolean': {
+            case 'boolean':
                 $variable = $element->nodeValue == 'true' ? true : false;
-                }
-            break;
+                break;
 
             case 'integer':
             case 'double':
-            case 'string': {
+            case 'string':
                 $variable = $element->nodeValue;
 
                 settype($variable, $element->tagName);
-                }
-            break;
+                break;
         }
 
         return $variable;
@@ -306,8 +254,6 @@ class PHPUnit_Util_XML
      * @return array
      * @throws PHPUnit_Framework_Exception
      * @since  Method available since Release 3.3.0
-     * @author Mike Naberezny <mike@maintainable.com>
-     * @author Derek DeVries <derek@maintainable.com>
      */
     public static function assertValidKeys(array $hash, array $validKeys)
     {
@@ -352,17 +298,17 @@ class PHPUnit_Util_XML
      * @param  mixed  $content
      * @return array
      * @since  Method available since Release 3.3.0
-     * @author Mike Naberezny <mike@maintainable.com>
-     * @author Derek DeVries <derek@maintainable.com>
      */
     public static function convertSelectToTag($selector, $content = true)
     {
-        $selector = trim(preg_replace("/\s+/", " ", $selector));
+        $selector = trim(preg_replace("/\s+/", ' ', $selector));
 
         // substitute spaces within attribute value
         while (preg_match('/\[[^\]]+"[^"]+\s[^"]+"\]/', $selector)) {
             $selector = preg_replace(
-                '/(\[[^\]]+"[^"]+)\s([^"]+"\])/', "$1__SPACE__$2", $selector
+                '/(\[[^\]]+"[^"]+)\s([^"]+"\])/',
+                '$1__SPACE__$2',
+                $selector
             );
         }
 
@@ -401,7 +347,9 @@ class PHPUnit_Util_XML
             // match attributes (\[[^\]]*\]*), ids (#[^\.#\[]*),
             // and classes (\.[^\.#\[]*))
             preg_match_all(
-                "/(\[[^\]]*\]*|#[^\.#\[]*|\.[^\.#\[]*)/", $element, $matches
+                "/(\[[^\]]*\]*|#[^\.#\[]*|\.[^\.#\[]*)/",
+                $element,
+                $matches
             );
 
             if (!empty($matches[1])) {
@@ -439,7 +387,7 @@ class PHPUnit_Util_XML
                 }
 
                 if ($classes) {
-                    $tag['class'] = join(' ', $classes);
+                    $tag['class'] = implode(' ', $classes);
                 }
 
                 if ($attrs) {
@@ -480,15 +428,12 @@ class PHPUnit_Util_XML
      * The $actual document may be a DOMDocument or a string
      * containing XML or HTML, identified by $isHtml.
      *
-     * @param  array         $selector
-     * @param  string        $content
-     * @param  mixed         $actual
-     * @param  boolean       $isHtml
-     * @return boolean|array
+     * @param  array      $selector
+     * @param  string     $content
+     * @param  mixed      $actual
+     * @param  bool       $isHtml
+     * @return bool|array
      * @since  Method available since Release 3.3.0
-     * @author Mike Naberezny <mike@maintainable.com>
-     * @author Derek DeVries <derek@maintainable.com>
-     * @author Tobias Schlitt <toby@php.net>
      */
     public static function cssSelect($selector, $content, $actual, $isHtml = true)
     {
@@ -504,12 +449,9 @@ class PHPUnit_Util_XML
      *
      * @param  DOMDocument $dom
      * @param  array       $options
-     * @param  boolean     $isHtml
+     * @param  bool        $isHtml
      * @return array
      * @since  Method available since Release 3.3.0
-     * @author Mike Naberezny <mike@maintainable.com>
-     * @author Derek DeVries <derek@maintainable.com>
-     * @author Tobias Schlitt <toby@php.net>
      */
     public static function findNodes(DOMDocument $dom, array $options, $isHtml = true)
     {
@@ -534,7 +476,8 @@ class PHPUnit_Util_XML
         if ($options['tag']) {
             if ($isHtml) {
                 $elements = self::getElementsByCaseInsensitiveTagName(
-                    $dom, $options['tag']
+                    $dom,
+                    $options['tag']
                 );
             } else {
                 $elements = $dom->getElementsByTagName($options['tag']);
@@ -572,7 +515,8 @@ class PHPUnit_Util_XML
             foreach ($tags as $tag) {
                 if ($isHtml) {
                     $elements = self::getElementsByCaseInsensitiveTagName(
-                        $dom, $tag
+                        $dom,
+                        $tag
                     );
                 } else {
                     $elements = $dom->getElementsByTagName($tag);
@@ -603,12 +547,13 @@ class PHPUnit_Util_XML
                     elseif ($name == 'class') {
                         // split to individual classes
                         $findClasses = explode(
-                            ' ', preg_replace("/\s+/", " ", $value)
+                            ' ',
+                            preg_replace("/\s+/", ' ', $value)
                         );
 
                         $allClasses = explode(
                             ' ',
-                            preg_replace("/\s+/", " ", $node->getAttribute($name))
+                            preg_replace("/\s+/", ' ', $node->getAttribute($name))
                         );
 
                         // make sure each class given is in the actual node
@@ -800,7 +745,8 @@ class PHPUnit_Util_XML
         if ($options['children']) {
             $validChild   = array('count', 'greater_than', 'less_than', 'only');
             $childOptions = self::assertValidKeys(
-                $options['children'], $validChild
+                $options['children'],
+                $validChild
             );
 
             foreach ($nodes as $node) {
@@ -842,7 +788,9 @@ class PHPUnit_Util_XML
                     // match each child against a specific tag
                     if ($childOptions['only']) {
                         $onlyNodes = self::findNodes(
-                            $dom, $childOptions['only'], $isHtml
+                            $dom,
+                            $childOptions['only'],
+                            $isHtml
                         );
 
                         // try to match each child to one of the 'only' nodes
@@ -882,8 +830,6 @@ class PHPUnit_Util_XML
      * @param  DOMNode $node
      * @return array
      * @since  Method available since Release 3.3.0
-     * @author Mike Naberezny <mike@maintainable.com>
-     * @author Derek DeVries <derek@maintainable.com>
      */
     protected static function getDescendants(DOMNode $node)
     {
@@ -928,8 +874,6 @@ class PHPUnit_Util_XML
      * @param  DOMNode $node
      * @return string
      * @since  Method available since Release 3.3.0
-     * @author Mike Naberezny <mike@maintainable.com>
-     * @author Derek DeVries <derek@maintainable.com>
      */
     protected static function getNodeText(DOMNode $node)
     {
